# Loducode web3

Basic components for the development of loducode s.a.s.

### install

`pip install loducode_web3==0.1.0`

## functionalities

- **Admin**
    - LandAdmin
    - NftAdmin
- **Models**
    - AttributeNft
    - Nft

## Commands

- python setup.py sdist bdist_wheel
- twine upload --repository pypi dist/loducode_web3-0.0.3*

entrar a la carpeta loducode_web3 y correr
- django-admin makemessages
- django-admin compilemessages

####Version 0.1.0
- Models abstracts

####Version 0.0.1
- first version

####Version 0.0.2
- bug imports

####Version 0.0.1
- first version
